
Automated spamming via feedback scripts
-------

**Description:**

A hacker must not gain the possibility to abuse an applications email functionality by 
means of scripts which sends automated spamming mails.


**Solution:**

This problem could be prevented by implementing CAPTCHA or rate-limiting mechanisms.
	